Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1047)

Unified Diff: media/ffmpeg/ffmpeg_common.h

Issue 1534273002: Switch to standard integer types in media/. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: more Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: media/ffmpeg/ffmpeg_common.h
diff --git a/media/ffmpeg/ffmpeg_common.h b/media/ffmpeg/ffmpeg_common.h
index 955ee645151218c684e88754ef34d09c33a70917..df4bab5629a7290c80ae07203c5f5d50b7e89fdf 100644
--- a/media/ffmpeg/ffmpeg_common.h
+++ b/media/ffmpeg/ffmpeg_common.h
@@ -75,19 +75,19 @@ inline void ScopedPtrAVFreeFrame::operator()(void* x) const {
av_frame_free(&frame);
}
// Converts an int64 timestamp in |time_base| units to a base::TimeDelta.
// For example if |timestamp| equals 11025 and |time_base| equals {1, 44100}
// then the return value will be a base::TimeDelta for 0.25 seconds since that
// is how much time 11025/44100ths of a second represents.
MEDIA_EXPORT base::TimeDelta ConvertFromTimeBase(const AVRational& time_base,
- int64 timestamp);
+ int64_t timestamp);
-// Converts a base::TimeDelta into an int64 timestamp in |time_base| units.
+// Converts a base::TimeDelta into an int64_t timestamp in |time_base| units.
// For example if |timestamp| is 0.5 seconds and |time_base| is {1, 44100}, then
// the return value will be 22050 since that is how many 1/44100ths of a second
// represent 0.5 seconds.
-MEDIA_EXPORT int64 ConvertToTimeBase(const AVRational& time_base,
- const base::TimeDelta& timestamp);
+MEDIA_EXPORT int64_t ConvertToTimeBase(const AVRational& time_base,
+ const base::TimeDelta& timestamp);
// Returns true if AVStream is successfully converted to a AudioDecoderConfig.
// Returns false if conversion fails, in which case |config| is not modified.
@@ -75,19 +75,19 @@ inline void ScopedPtrAVFreeFrame::operator()(void* x) const {
av_frame_free(&frame);
}
-// Converts an int64 timestamp in |time_base| units to a base::TimeDelta.
+// Converts an int64_t timestamp in |time_base| units to a base::TimeDelta.
// For example if |timestamp| equals 11025 and |time_base| equals {1, 44100}
// then the return value will be a base::TimeDelta for 0.25 seconds since that

Powered by Google App Engine
This is Rietveld 408576698